.. SPDX-License-Identifier: GPL-3.0-or-later
.. FileType: DOCUMENTATION
.. SPDX-FileCopyrightText: 2025 GFZ Helmholtz Centre for Geosciences
.. SPDX-FileCopyrightText: 2025, "Eva Boergens" at GFZ Potsdam



=======
Credits
=======

Development Lead
----------------

* Eva Boergens <eva.boergens@gfz.de>

Contributors - code development
-------------------------------
(alphabetical order)

* Aleeda Charly
* Martin Horwath
* Daniela Rabe
* Daniel Scheffler
* Linus Shihora
* Josefine Wilms


Contributors - heritage code
----------------------------
(alphabetical order)

* Inga Bergmann-Wolf
* Christoph Dahle
* Robert Dill
* Henryk Dobslaw
* Thorben Döhne
* Andreas Groh
* Roelof Rietbroek

Project management and funding
------------------------------
* Eva Boergens <eva.boergens@gfz.de>
* Martin Horwath <martin.horwath@tu-dresden.de>
* Henryk Dobslaw <henryk.dobslaw@gfz.de>
